# Building structured multi-plot grids

When exploring medium-dimensional data, a useful approach is to draw multiple instances of the same plot on different subsets of your dataset. This technique is sometimes called either “lattice”, or “trellis” plotting, and it is related to the idea of [“small multiples”](https://en.wikipedia.org/wiki/Small_multiple). It allows a viewer to quickly extract a large amount of information about complex data. Matplotlib offers good support for making figures with multiple axes; seaborn builds on top of this to directly link the structure of the plot to the structure of your dataset.

To use these features, your data has to be in a Pandas DataFrame and it must take the form of what Hadley Whickam calls [“tidy” data](https://vita.had.co.nz/papers/tidy-data.pdf). In brief, that means your dataframe should be structured such that each column is a variable and each row is an observation.

For advanced use, you can use the objects discussed in this part of the tutorial directly, which will provide maximum flexibility. Some seaborn functions (such as [`lmplot()`](../generated/seaborn.lmplot.html#seaborn.lmplot "seaborn.lmplot"), [`catplot()`](../generated/seaborn.catplot.html#seaborn.catplot "seaborn.catplot"), and [`pairplot()`](../generated/seaborn.pairplot.html#seaborn.pairplot "seaborn.pairplot")) also use them behind the scenes. Unlike other seaborn functions that are “Axes-level” and draw onto specific (possibly already-existing) matplotlib `Axes` without otherwise manipulating the figure, these higher-level functions create a figure when called and are generally more strict about how it gets set up. In some cases, arguments either to those functions or to the constructor of the class they rely on will provide a different interface attributes like the figure size, as in the case of [`lmplot()`](../generated/seaborn.lmplot.html#seaborn.lmplot "seaborn.lmplot") where you can set the height and aspect ratio for each facet rather than the overall size of the figure. Any function that uses one of these objects will always return it after plotting, though, and most of these objects have convenience methods for changing how the plot is drawn, often in a more abstract and easy way.

```py
import seaborn as sns
import matplotlib.pyplot as plt

```

```py
sns.set(style="ticks")

```

## Conditional small multiples

The [`FacetGrid`](../generated/seaborn.FacetGrid.html#seaborn.FacetGrid "seaborn.FacetGrid") class is useful when you want to visualize the distribution of a variable or the relationship between multiple variables separately within subsets of your dataset. A [`FacetGrid`](../generated/seaborn.FacetGrid.html#seaborn.FacetGrid "seaborn.FacetGrid") can be drawn with up to three dimensions: `row`, `col`, and `hue`. The first two have obvious correspondence with the resulting array of axes; think of the hue variable as a third dimension along a depth axis, where different levels are plotted with different colors.

The class is used by initializing a [`FacetGrid`](../generated/seaborn.FacetGrid.html#seaborn.FacetGrid "seaborn.FacetGrid") object with a dataframe and the names of the variables that will form the row, column, or hue dimensions of the grid. These variables should be categorical or discrete, and then the data at each level of the variable will be used for a facet along that axis. For example, say we wanted to examine differences between lunch and dinner in the `tips` dataset.

Additionally, each of [`relplot()`](../generated/seaborn.relplot.html#seaborn.relplot "seaborn.relplot"), [`catplot()`](../generated/seaborn.catplot.html#seaborn.catplot "seaborn.catplot"), and [`lmplot()`](../generated/seaborn.lmplot.html#seaborn.lmplot "seaborn.lmplot") use this object internally, and they return the object when they are finished so that it can be used for further tweaking.

```py
tips = sns.load_dataset("tips")

```

```py
g = sns.FacetGrid(tips, col="time")

```

![http://seaborn.pydata.org/_images/axis_grids_7_0.png](img/98101f3cd02be71d90f9d777eca5876f.jpg)

Initializing the grid like this sets up the matplotlib figure and axes, but doesn’t draw anything on them.

The main approach for visualizing data on this grid is with the [`FacetGrid.map()`](../generated/seaborn.FacetGrid.map.html#seaborn.FacetGrid.map "seaborn.FacetGrid.map") method. Provide it with a plotting function and the name(s) of variable(s) in the dataframe to plot. Let’s look at the distribution of tips in each of these subsets, using a histogram.

```py
g = sns.FacetGrid(tips, col="time")
g.map(plt.hist, "tip");

```

![http://seaborn.pydata.org/_images/axis_grids_9_0.png](img/5e335e837566d00501c0389d96625993.jpg)

This function will draw the figure and annotate the axes, hopefully producing a finished plot in one step. To make a relational plot, just pass multiple variable names. You can also provide keyword arguments, which will be passed to the plotting function:

```py
g = sns.FacetGrid(tips, col="sex", hue="smoker")
g.map(plt.scatter, "total_bill", "tip", alpha=.7)
g.add_legend();

```

![http://seaborn.pydata.org/_images/axis_grids_11_0.png](img/96cf02373c746bde1b58beb44b2f25c8.jpg)

There are several options for controlling the look of the grid that can be passed to the class constructor.

```py
g = sns.FacetGrid(tips, row="smoker", col="time", margin_titles=True)
g.map(sns.regplot, "size", "total_bill", color=".3", fit_reg=False, x_jitter=.1);

```

![http://seaborn.pydata.org/_images/axis_grids_13_0.png](img/8da0c248ec165400ddf3c27f13d9a824.jpg)

Note that `margin_titles` isn’t formally supported by the matplotlib API, and may not work well in all cases. In particular, it currently can’t be used with a legend that lies outside of the plot.

The size of the figure is set by providing the height of _each_ facet, along with the aspect ratio:

```py
g = sns.FacetGrid(tips, col="day", height=4, aspect=.5)
g.map(sns.barplot, "sex", "total_bill");

```

```py
/Users/mwaskom/code/seaborn/seaborn/axisgrid.py:715: UserWarning: Using the barplot function without specifying order is likely to produce an incorrect plot.
  warnings.warn(warning)

```

![http://seaborn.pydata.org/_images/axis_grids_15_1.png](img/05a2ee4e2b81712775628943c2135066.jpg)

The default ordering of the facets is derived from the information in the DataFrame. If the variable used to define facets has a categorical type, then the order of the categories is used. Otherwise, the facets will be in the order of appearance of the category levels. It is possible, however, to specify an ordering of any facet dimension with the appropriate `*_order` parameter:

```py
ordered_days = tips.day.value_counts().index
g = sns.FacetGrid(tips, row="day", row_order=ordered_days,
                  height=1.7, aspect=4,)
g.map(sns.distplot, "total_bill", hist=False, rug=True);

```

![http://seaborn.pydata.org/_images/axis_grids_17_0.png](img/0140b6849cae4a202c9a56ad5edfffd6.jpg)

Any seaborn color palette (i.e., something that can be passed to [`color_palette()`](../generated/seaborn.color_palette.html#seaborn.color_palette "seaborn.color_palette") can be provided. You can also use a dictionary that maps the names of values in the `hue` variable to valid matplotlib colors:

```py
pal = dict(Lunch="seagreen", Dinner="gray")
g = sns.FacetGrid(tips, hue="time", palette=pal, height=5)
g.map(plt.scatter, "total_bill", "tip", s=50, alpha=.7, linewidth=.5, edgecolor="white")
g.add_legend();

```

![http://seaborn.pydata.org/_images/axis_grids_19_0.png](img/686b61f7ba884a08ccd40cd9aae45791.jpg)

You can also let other aspects of the plot vary across levels of the hue variable, which can be helpful for making plots that will be more comprehensible when printed in black-and-white. To do this, pass a dictionary to `hue_kws` where keys are the names of plotting function keyword arguments and values are lists of keyword values, one for each level of the hue variable.

```py
g = sns.FacetGrid(tips, hue="sex", palette="Set1", height=5, hue_kws={"marker": ["^", "v"]})
g.map(plt.scatter, "total_bill", "tip", s=100, linewidth=.5, edgecolor="white")
g.add_legend();

```

![http://seaborn.pydata.org/_images/axis_grids_21_0.png](img/a99d865fc52a457633d59e779fb194f1.jpg)

If you have many levels of one variable, you can plot it along the columns but “wrap” them so that they span multiple rows. When doing this, you cannot use a `row` variable.

```py
attend = sns.load_dataset("attention").query("subject <= 12")
g = sns.FacetGrid(attend, col="subject", col_wrap=4, height=2, ylim=(0, 10))
g.map(sns.pointplot, "solutions", "score", color=".3", ci=None);

```

```py
/Users/mwaskom/code/seaborn/seaborn/axisgrid.py:715: UserWarning: Using the pointplot function without specifying order is likely to produce an incorrect plot.
  warnings.warn(warning)

```

![http://seaborn.pydata.org/_images/axis_grids_23_1.png](img/5291ce95bb602839ea9bb9b4e3e7d128.jpg)

Once you’ve drawn a plot using [`FacetGrid.map()`](../generated/seaborn.FacetGrid.map.html#seaborn.FacetGrid.map "seaborn.FacetGrid.map") (which can be called multiple times), you may want to adjust some aspects of the plot. There are also a number of methods on the [`FacetGrid`](../generated/seaborn.FacetGrid.html#seaborn.FacetGrid "seaborn.FacetGrid") object for manipulating the figure at a higher level of abstraction. The most general is `FacetGrid.set()`, and there are other more specialized methods like `FacetGrid.set_axis_labels()`, which respects the fact that interior facets do not have axis labels. For example:

```py
with sns.axes_style("white"):
    g = sns.FacetGrid(tips, row="sex", col="smoker", margin_titles=True, height=2.5)
g.map(plt.scatter, "total_bill", "tip", color="#334488", edgecolor="white", lw=.5);
g.set_axis_labels("Total bill (US Dollars)", "Tip");
g.set(xticks=[10, 30, 50], yticks=[2, 6, 10]);
g.fig.subplots_adjust(wspace=.02, hspace=.02);

```

![http://seaborn.pydata.org/_images/axis_grids_25_0.png](img/9127880f623ed92358326c68893d22b4.jpg)

For even more customization, you can work directly with the underling matplotlib `Figure` and `Axes` objects, which are stored as member attributes at `fig` and `axes` (a two-dimensional array), respectively. When making a figure without row or column faceting, you can also use the `ax` attribute to directly access the single axes.

```py
g = sns.FacetGrid(tips, col="smoker", margin_titles=True, height=4)
g.map(plt.scatter, "total_bill", "tip", color="#338844", edgecolor="white", s=50, lw=1)
for ax in g.axes.flat:
    ax.plot((0, 50), (0, .2 * 50), c=".2", ls="--")
g.set(xlim=(0, 60), ylim=(0, 14));

```

![http://seaborn.pydata.org/_images/axis_grids_27_0.png](img/a7e016f2ed7f61c499c7f56b2f3d8350.jpg)

## Using custom functions

You’re not limited to existing matplotlib and seaborn functions when using [`FacetGrid`](../generated/seaborn.FacetGrid.html#seaborn.FacetGrid "seaborn.FacetGrid"). However, to work properly, any function you use must follow a few rules:

1.  It must plot onto the “currently active” matplotlib `Axes`. This will be true of functions in the `matplotlib.pyplot` namespace, and you can call `plt.gca` to get a reference to the current `Axes` if you want to work directly with its methods.
2.  It must accept the data that it plots in positional arguments. Internally, [`FacetGrid`](../generated/seaborn.FacetGrid.html#seaborn.FacetGrid "seaborn.FacetGrid") will pass a `Series` of data for each of the named positional arguments passed to [`FacetGrid.map()`](../generated/seaborn.FacetGrid.map.html#seaborn.FacetGrid.map "seaborn.FacetGrid.map").
3.  It must be able to accept `color` and `label` keyword arguments, and, ideally, it will do something useful with them. In most cases, it’s easiest to catch a generic dictionary of `**kwargs` and pass it along to the underlying plotting function.

Let’s look at minimal example of a function you can plot with. This function will just take a single vector of data for each facet:

```py
from scipy import stats
def quantile_plot(x, **kwargs):
    qntls, xr = stats.probplot(x, fit=False)
    plt.scatter(xr, qntls, **kwargs)

g = sns.FacetGrid(tips, col="sex", height=4)
g.map(quantile_plot, "total_bill");

```

![http://seaborn.pydata.org/_images/axis_grids_29_0.png](img/f7075e926868bca0186de8da2f906ed9.jpg)

If we want to make a bivariate plot, you should write the function so that it accepts the x-axis variable first and the y-axis variable second:

```py
def qqplot(x, y, **kwargs):
    _, xr = stats.probplot(x, fit=False)
    _, yr = stats.probplot(y, fit=False)
    plt.scatter(xr, yr, **kwargs)

g = sns.FacetGrid(tips, col="smoker", height=4)
g.map(qqplot, "total_bill", "tip");

```

![http://seaborn.pydata.org/_images/axis_grids_31_0.png](img/b9d0e6d4b79fc2df3e1a1edcdd37e5ec.jpg)

Because `plt.scatter` accepts `color` and `label` keyword arguments and does the right thing with them, we can add a hue facet without any difficulty:

```py
g = sns.FacetGrid(tips, hue="time", col="sex", height=4)
g.map(qqplot, "total_bill", "tip")
g.add_legend();

```

![http://seaborn.pydata.org/_images/axis_grids_33_0.png](img/9d51f61931446dc9eccd2013f7666eb9.jpg)

This approach also lets us use additional aesthetics to distinguish the levels of the hue variable, along with keyword arguments that won’t be dependent on the faceting variables:

```py
g = sns.FacetGrid(tips, hue="time", col="sex", height=4,
                  hue_kws={"marker": ["s", "D"]})
g.map(qqplot, "total_bill", "tip", s=40, edgecolor="w")
g.add_legend();

```

![http://seaborn.pydata.org/_images/axis_grids_35_0.png](img/894a1105419e7147b562c1576471c410.jpg)

Sometimes, though, you’ll want to map a function that doesn’t work the way you expect with the `color` and `label` keyword arguments. In this case, you’ll want to explicitly catch them and handle them in the logic of your custom function. For example, this approach will allow use to map `plt.hexbin`, which otherwise does not play well with the [`FacetGrid`](../generated/seaborn.FacetGrid.html#seaborn.FacetGrid "seaborn.FacetGrid") API:

```py
def hexbin(x, y, color, **kwargs):
    cmap = sns.light_palette(color, as_cmap=True)
    plt.hexbin(x, y, gridsize=15, cmap=cmap, **kwargs)

with sns.axes_style("dark"):
    g = sns.FacetGrid(tips, hue="time", col="time", height=4)
g.map(hexbin, "total_bill", "tip", extent=[0, 50, 0, 10]);

```

![http://seaborn.pydata.org/_images/axis_grids_37_0.png](img/6e0f3ad155ad03e98d1e10abc9d60e82.jpg)

## Plotting pairwise data relationships

[`PairGrid`](../generated/seaborn.PairGrid.html#seaborn.PairGrid "seaborn.PairGrid") also allows you to quickly draw a grid of small subplots using the same plot type to visualize data in each. In a [`PairGrid`](../generated/seaborn.PairGrid.html#seaborn.PairGrid "seaborn.PairGrid"), each row and column is assigned to a different variable, so the resulting plot shows each pairwise relationship in the dataset. This style of plot is sometimes called a “scatterplot matrix”, as this is the most common way to show each relationship, but [`PairGrid`](../generated/seaborn.PairGrid.html#seaborn.PairGrid "seaborn.PairGrid") is not limited to scatterplots.

It’s important to understand the differences between a [`FacetGrid`](../generated/seaborn.FacetGrid.html#seaborn.FacetGrid "seaborn.FacetGrid") and a [`PairGrid`](../generated/seaborn.PairGrid.html#seaborn.PairGrid "seaborn.PairGrid"). In the former, each facet shows the same relationship conditioned on different levels of other variables. In the latter, each plot shows a different relationship (although the upper and lower triangles will have mirrored plots). Using [`PairGrid`](../generated/seaborn.PairGrid.html#seaborn.PairGrid "seaborn.PairGrid") can give you a very quick, very high-level summary of interesting relationships in your dataset.

The basic usage of the class is very similar to [`FacetGrid`](../generated/seaborn.FacetGrid.html#seaborn.FacetGrid "seaborn.FacetGrid"). First you initialize the grid, then you pass plotting function to a `map` method and it will be called on each subplot. There is also a companion function, [`pairplot()`](../generated/seaborn.pairplot.html#seaborn.pairplot "seaborn.pairplot") that trades off some flexibility for faster plotting.

```py
iris = sns.load_dataset("iris")
g = sns.PairGrid(iris)
g.map(plt.scatter);

```

![http://seaborn.pydata.org/_images/axis_grids_39_0.png](img/4a1b1a2445b45757efa39039fe666d0f.jpg)

It’s possible to plot a different function on the diagonal to show the univariate distribution of the variable in each column. Note that the axis ticks won’t correspond to the count or density axis of this plot, though.

```py
g = sns.PairGrid(iris)
g.map_diag(plt.hist)
g.map_offdiag(plt.scatter);

```

![http://seaborn.pydata.org/_images/axis_grids_41_0.png](img/e6b76ab1dc666e53ba77d9784aa8d168.jpg)

A very common way to use this plot colors the observations by a separate categorical variable. For example, the iris dataset has four measurements for each of three different species of iris flowers so you can see how they differ.

```py
g = sns.PairGrid(iris, hue="species")
g.map_diag(plt.hist)
g.map_offdiag(plt.scatter)
g.add_legend();

```

![http://seaborn.pydata.org/_images/axis_grids_43_0.png](img/31d92e08bdcc758f28b32f9a6f31aff7.jpg)

By default every numeric column in the dataset is used, but you can focus on particular relationships if you want.

```py
g = sns.PairGrid(iris, vars=["sepal_length", "sepal_width"], hue="species")
g.map(plt.scatter);

```

![http://seaborn.pydata.org/_images/axis_grids_45_0.png](img/8bd8dc270d4a00dd45e740cdf68fcf23.jpg)

It’s also possible to use a different function in the upper and lower triangles to emphasize different aspects of the relationship.

```py
g = sns.PairGrid(iris)
g.map_upper(plt.scatter)
g.map_lower(sns.kdeplot)
g.map_diag(sns.kdeplot, lw=3, legend=False);

```

![http://seaborn.pydata.org/_images/axis_grids_47_0.png](img/05cf1fb72d609a18fa7a4fdfb8ae460f.jpg)

The square grid with identity relationships on the diagonal is actually just a special case, and you can plot with different variables in the rows and columns.

```py
g = sns.PairGrid(tips, y_vars=["tip"], x_vars=["total_bill", "size"], height=4)
g.map(sns.regplot, color=".3")
g.set(ylim=(-1, 11), yticks=[0, 5, 10]);

```

![http://seaborn.pydata.org/_images/axis_grids_49_0.png](img/1519f7f68ebbc0bf3fa3072a2edb0838.jpg)

Of course, the aesthetic attributes are configurable. For instance, you can use a different palette (say, to show an ordering of the `hue` variable) and pass keyword arguments into the plotting functions.

```py
g = sns.PairGrid(tips, hue="size", palette="GnBu_d")
g.map(plt.scatter, s=50, edgecolor="white")
g.add_legend();

```

![http://seaborn.pydata.org/_images/axis_grids_51_0.png](img/472e90723a05c450ec78ccf39888e6e4.jpg)

[`PairGrid`](../generated/seaborn.PairGrid.html#seaborn.PairGrid "seaborn.PairGrid") is flexible, but to take a quick look at a dataset, it can be easier to use [`pairplot()`](../generated/seaborn.pairplot.html#seaborn.pairplot "seaborn.pairplot"). This function uses scatterplots and histograms by default, although a few other kinds will be added (currently, you can also plot regression plots on the off-diagonals and KDEs on the diagonal).

```py
sns.pairplot(iris, hue="species", height=2.5);

```

![http://seaborn.pydata.org/_images/axis_grids_53_0.png](img/27d73e1a33e6845f05c2a4670413c156.jpg)

You can also control the aesthetics of the plot with keyword arguments, and it returns the [`PairGrid`](../generated/seaborn.PairGrid.html#seaborn.PairGrid "seaborn.PairGrid") instance for further tweaking.

```py
g = sns.pairplot(iris, hue="species", palette="Set2", diag_kind="kde", height=2.5)

```

![http://seaborn.pydata.org/_images/axis_grids_55_0.png](img/62af2a2066c78c192cde66155a2331d9.jpg)